==> hiver-common-1.0.0-sources.jar: plus/hiver/common/base/HiverBaseEntity.java <==
/*
 * Copyright 2023-2025 Licensed under the AGPL License
 */
package plus.hiver.common.base;

import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableLogic;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import io.swagger.v3.oas.annotations.media.Schema;
import jakarta.persistence.EntityListeners;
import jakarta.persistence.MappedSuperclass;
import jakarta.validation.constraints.NotNull;
import jakarta.validation.constraints.Null;
import lombok.Data;
import org.springframework.data.annotation.*;
import org.springframework.data.jpa.domain.support.AuditingEntityListener;
import org.springframework.format.annotation.DateTimeFormat;
import plus.hiver.common.constant.HiverConstant;
import plus.hiver.common.utils.SnowFlakeUtil;
import plus.hiver.common.validation.Create;
import plus.hiver.common.validation.Update;

import java.io.Serializable;
import java.util.Date;

/**
 * 实体抽象类
 *
 * <p>
 * 尊重知识产权，CV 请保留版权，海文科技 https://hiver.cc 出品，不允许非法使用，后果自负
 * </p>
 *
 * @author Yazhi Li
 */
@Data
@MappedSuperclass
@EntityListeners(AuditingEntityListener.class)
@JsonIgnoreProperties(value = {"hibernateLazyInitializer", "handler", "fieldHandler"})
public abstract class HiverBaseEntity implements HiverBeanConvert, Serializable {
    private static final long serialVersionUID = 1L;

    @Id
    @TableId
    @Schema(description = "主键")
    @Null(groups = Create.class)
    @NotNull(groups = Update.class)
    private Long id = SnowFlakeUtil.nextId();

    @Schema(description = "创建人ID")
    @TableField(fill = FieldFill.INSERT)
    private String createId;

    @Schema(description = "创建者")
    @CreatedBy
    @TableField(fill = FieldFill.INSERT)
    private String createBy;

    @CreatedDate
    @JsonFormat(timezone = HiverConstant.GMT8, pattern = HiverConstant.DATE_MM_SS)
    @DateTimeFormat(pattern = HiverConstant.DATE_MM_SS)
    @Schema(description = "创建时间")
    private Date createTime;

    @Schema(description = "更新者")
    @LastModifiedBy
    @TableField(fill = FieldFill.UPDATE)
    private String updateBy;

    @LastModifiedDate
    @JsonFormat(timezone = HiverConstant.GMT8, pattern = HiverConstant.DATE_MM_SS)
    @DateTimeFormat(pattern = HiverConstant.DATE_MM_SS)
    @Schema(description = "更新时间")
    @TableField(fill = FieldFill.UPDATE)
    private Date updateTime;

    @JsonIgnore
    @TableLogic(value = "0", delval = "1")
    @Schema(description = "删除标志 默认0")
    private Integer deleted = HiverConstant.STATUS_NORMAL;
}

==> hiver-common-1.0.3-sources.jar: plus/hiver/common/base/HiverBaseEntity.java <==
/*
 * Copyright 2023-2025 Licensed under the AGPL License
 */
package plus.hiver.common.base;

import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableLogic;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import io.swagger.v3.oas.annotations.media.Schema;
import jakarta.persistence.EntityListeners;
import jakarta.persistence.Id;
import jakarta.persistence.MappedSuperclass;
import lombok.Data;
import org.springframework.data.annotation.*;
import org.springframework.data.jpa.domain.support.AuditingEntityListener;
import org.springframework.format.annotation.DateTimeFormat;
import plus.hiver.common.constant.HiverConstant;
import plus.hiver.common.utils.SnowFlakeUtil;

import java.io.Serializable;
import java.util.Date;

/**
 * 实体抽象类
 *
 * <p>
 * 尊重知识产权，CV 请保留版权，海文科技 https://hiver.cc 出品，不允许非法使用，后果自负
 * </p>
 *
 * @author Yazhi Li
 */
@Data
@MappedSuperclass
@EntityListeners(AuditingEntityListener.class)
@JsonIgnoreProperties(value = {"hibernateLazyInitializer", "handler", "fieldHandler"})
public abstract class HiverBaseEntity implements Serializable {
    private static final long serialVersionUID = 1L;

    @Id
    @TableId
    @Schema(description = "主键")
    private Long id = SnowFlakeUtil.nextId();

    @Schema(description = "创建人ID")
    @TableField(fill = FieldFill.INSERT)
    private String createId;

    @Schema(description = "创建者")
    @CreatedBy
    @TableField(fill = FieldFill.INSERT)
    private String createBy;

    @CreatedDate
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Schema(description = "创建时间")
    private Date createTime;

    @Schema(description = "更新者")
    @LastModifiedBy
    @TableField(fill = FieldFill.UPDATE)
    private String updateBy;

    @LastModifiedDate
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Schema(description = "更新时间")
    @TableField(fill = FieldFill.UPDATE)
    private Date updateTime;

    @JsonIgnore
    @TableLogic(value = "0", delval = "1")
    @Schema(description = "删除标志 默认0")
    private Integer deleted = HiverConstant.STATUS_NORMAL;
}
